@@ -83,14 +83,25 @@ static ADDRESS *mutt_expand_aliases_r (ADDRESS *a, LIST **expn)
       else
       {
 	struct passwd *pw = getpwnam (a->mailbox);
-	char buffer[256], *p;
 
 	if (pw)
 	{
-	  strfcpy (buffer, pw->pw_gecos, sizeof (buffer));
-	  if ((p = strchr (buffer, ',')))
-	    *p = 0;
-	  a->personal = safe_strdup (buffer);
+           regmatch_t pat_match[1];
+
+           /* Use regular expression to parse Gecos field.  This result of the
+            * parsing will be used as the personal ID string when the alias is
+            * expanded.
+            */
+	  if (regexec (GecosMask.rx, pw->pw_gecos, 1, pat_match, 0) == 0)
+	  {
+	    /* Malloc enough for the matching pattern + terminating NULL */
+	    a->personal = safe_malloc ((pat_match[0].rm_eo - 
+					pat_match[0].rm_so) + 1);
+	    
+	    strfcpy (a->personal, pw->pw_gecos + pat_match[0].rm_so, 
+		     pat_match[0].rm_eo - pat_match[0].rm_so + 1);
+	  }
+
 #ifdef EXACT_ADDRESS
 	  FREE (&a->val);
 #endif
@@ -128,7 +139,8 @@ ADDRESS *mutt_expand_aliases (ADDRESS *a)
   return (t);
 }
 
-/* if someone has an address like
+/* 
+ * if someone has an address like
  *	From: Michael `/bin/rm -f ~` Elkins <me@cs.hmc.edu>
  * and the user creates an alias for this, Mutt could wind up executing
  * the backtics because it writes aliases like
@@ -140,18 +152,60 @@ ADDRESS *mutt_expand_aliases (ADDRESS *a)
  * since that would get aliased as
  *	alias me Michael \\`/bin/rm -f ~\\` Elkins <me@cs.hmc.edu>
  * which still gets evaluated because the double backslash is not a quote.
+ * 
+ * Additionally, we need to quote ' and " characters - otherwise, mutt will
+ * interpret them on the wrong parsing step.
+ * 
+ * $ wants to be quoted since it may indicate the start of an environment
+ * variable.
  */
+
 static void write_safe_address (FILE *fp, char *s)
 {
   while (*s)
   {
-    if (*s == '\\' || *s == '`')
+    if (*s == '\\' || *s == '`' || *s == '\'' || *s == '"'
+	|| *s == '$')
       fputc ('\\', fp);
     fputc (*s, fp);
     s++;
   }
 }
 
+ADDRESS *mutt_get_address (ENVELOPE *env, char **pfxp)
+{
+  ADDRESS *adr;
+  char *pfx = NULL;
+
+  if (mutt_addr_is_user (env->from))
+  {
+    if (env->to && !mutt_is_mail_list (env->to))
+    {
+      pfx = "To";
+      adr = env->to;
+    }
+    else
+    {
+      pfx = "Cc";
+      adr = env->cc;
+    }
+  }
+  else if (env->reply_to && !mutt_is_mail_list (env->reply_to))
+  {
+    pfx = "Reply-To";
+    adr = env->reply_to;
+  }
+  else
+  {
+    adr = env->from;
+    pfx = "From";
+  }
+
+  if (pfxp) *pfxp = pfx;
+
+  return adr;
+}
+
 void mutt_create_alias (ENVELOPE *cur, ADDRESS *iadr)
 {
   ALIAS *new, *t;
@@ -161,18 +215,7 @@ void mutt_create_alias (ENVELOPE *cur, ADDRESS *iadr)
 
   if (cur)
   {
-    if (mutt_addr_is_user (cur->from))
-    {
-      if (cur->to && !mutt_is_mail_list (cur->to))
-	adr = cur->to;
-      else
-	adr = cur->cc;
-    }
-    else if (cur->reply_to && !mutt_is_mail_list (cur->reply_to))
-      adr = cur->reply_to;
-    else
-      adr = cur->from;
-
+    adr = mutt_get_address (cur, NULL);
   }
   else if (iadr)
   {
@@ -397,11 +440,14 @@ int mutt_addr_is_user (ADDRESS *addr)
 
   if (mutt_strcasecmp (addr->mailbox, Username) == 0)
     return 1;
-  if(string_is_address(addr->mailbox, Username, Hostname))
+  if (string_is_address(addr->mailbox, Username, Hostname))
     return 1;
-  if(string_is_address(addr->mailbox, Username, mutt_fqdn(0)))
+  if (string_is_address(addr->mailbox, Username, mutt_fqdn(0)))
     return 1;
-  if(string_is_address(addr->mailbox, Username, mutt_fqdn(1)))
+  if (string_is_address(addr->mailbox, Username, mutt_fqdn(1)))
+    return 1;
+
+  if (From && !mutt_strcasecmp (From->mailbox, addr->mailbox))
     return 1;
 
   if (Alternates.pattern &&
