@@ -1,6 +1,6 @@
-/* $Id: browser.h,v 2.4 1999/08/15 11:43:03 roessler Exp $ */
+/* $Id: browser.h,v 2.6 2000/02/14 16:07:54 roessler Exp $ */
 /*
- * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -30,7 +30,11 @@ struct folder_file
   char *name;
   char *desc;
 #ifdef USE_IMAP
-  short notfolder;
+  char delim;
+  
+  unsigned imap : 1;
+  unsigned selectable : 1;
+  unsigned inferiors : 1;
 #endif
   unsigned tagged : 1;
   unsigned is_new : 1;
