@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -118,9 +118,11 @@ int test_new_folder (const char *path)
   if (typ != M_MBOX && typ != M_MMDF && typ != M_KENDRA)
     return 0;
 
-  f = fopen (path, "rb");
-  rc = test_last_status_new (f);
-  fclose (f);
+  if ((f = fopen (path, "rb")))
+  {
+    rc = test_last_status_new (f);
+    fclose (f);
+  }
 
   return rc;
 }
