@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 1998-2000Werner Koch <werner.koch@guug.de>
- * Copyright (C) 1999-2000Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1998-2000 Werner Koch <werner.koch@guug.de>
+ * Copyright (C) 1999-2000 Thomas Roessler <roessler@guug.de>
  *
  *     This program is free software; you can redistribute it
  *     and/or modify it under the terms of the GNU General Public
@@ -85,7 +85,7 @@ static void fix_uid (char *uid)
   }
   *d = '\0';
   
-  mutt_decode_utf8_string (d, _chs);
+  mutt_decode_utf8_string (uid, _chs);
 }
 
 static pgp_key_t *parse_pub_line (char *buf, int *is_subkey, pgp_key_t *k)
