@@ -21,6 +21,7 @@
 /* general IMAP utility functions */
 
 #include "mutt.h"
+#include "mx.h"	/* for M_IMAP */
 #include "imap_private.h"
 
 #include <stdlib.h>
@@ -304,8 +305,10 @@ int imap_wordcasecmp(const char *a, const char *b)
   return mutt_strcasecmp(a, tmp);
 }
 
-/* imap keepalive: use buffy to poll a remote imap folder
- * while waiting for an external process
+/* 
+ * Imap keepalive: poll the current folder to keep the
+ * connection alive.
+ * 
  */
 
 static RETSIGTYPE alrm_handler (int sig)
@@ -313,6 +316,17 @@ static RETSIGTYPE alrm_handler (int sig)
   /* empty */
 }
 
+void imap_keepalive (void)
+{
+  CONTEXT *ctx = Context;
+  
+  if (ctx == NULL || ctx->magic != M_IMAP ||
+      CTX_DATA->selected_ctx != ctx)
+    return;
+
+  imap_check_mailbox (ctx, NULL);
+}
+
 int imap_wait_keepalive (pid_t pid)
 {
   struct sigaction oldalrm;
@@ -341,9 +355,7 @@ int imap_wait_keepalive (pid_t pid)
   while (waitpid (pid, &rc, 0) < 0 && errno == EINTR)
   {
     alarm (0); /* cancel a possibly pending alarm */
-    if (!option (OPTMSGERR))
-      mutt_buffy_check (0);
-
+    imap_keepalive ();
     alarm (ImapCheckTimeout > 0 ? ImapCheckTimeout : 60);
   }
 
@@ -359,3 +371,16 @@ int imap_wait_keepalive (pid_t pid)
   return rc;
 }
 
+/* Allow/disallow re-opening a folder upon expunge. */
+
+void imap_allow_reopen (CONTEXT *ctx)
+{
+  if (ctx->magic == M_IMAP && CTX_DATA->selected_ctx == ctx)
+    CTX_DATA->reopen |= IMAP_REOPEN_ALLOW;
+}
+
+void imap_disallow_reopen (CONTEXT *ctx)
+{
+  if (ctx->magic == M_IMAP && CTX_DATA->selected_ctx == ctx)
+    CTX_DATA->reopen &= ~IMAP_REOPEN_ALLOW;
+}
